from nzshm_common.grids.io import latlon_from_base64_zip


class NZ01nb1v0:
    nz = None

    def load(self):
        if self.nz is None:
            self.nz = latlon_from_base64_zip(data)
        return self.nz


data = (
    "UEsDBD8AAgAOAHJZ81Q6lt94aQYAAJipAAAEAAAAZGF0YQkEBQBdAACAAAAY"
    "jaxcNpfygoevllxFWkF0RZzJXrt41v/3qEQcJILW2eVT9YyfGk8NRy8Z/+c6"
    "yMlji9f6EFImZ94p8AMP4CQk+TdFX+Jy+ruB6qW7Mng+qXtIGBBV+eznCl7h"
    "SLc2RaDifGmN+MrsGrRVK04cKItx6R7B4MiwHJUEU/jTCVrKFPFhzL+Gh4aN"
    "b+y6YtnIpO3j7eCDnFckPgxDblz10tJQVA9kJwCemvFLdeQAHou5BKe0Ohs1"
    "gdGrurND82Hz2v9COaxV1CibI0EIBt44DizqMlCdEo+oaCmL34dha8ePedJv"
    "N6cUCtAYM344A8QbG3D7k7DqeSFaBD5u2dY+Qcj7tNCROjdXr1W6fr6jD5ty"
    "udnR12eoOe+WYgh7Qsm/bjTFIPEBvhyUSfVzp8MYqViSRIHg6DnGgQeQDA9f"
    "/hxNPprmWRY8YQXtU5+54QTDsBfnMVzPlIiF73T3Ap3PV6ZvRSXXyJh6SYjE"
    "6pMHpvYcbWjHrNSptF76HH4XHQOm+PFmZz8AOBVcWdfRb7dpCCZ8LJS8anfK"
    "zmVvoq+Sha+GNZlcQAUdJSe6++7dTvcIrhFIe6bpnMiq1qQ7CJHB74l6DTTE"
    "ZAez0+uuGbfxQGi5QqeEwMVxW0bWQ52BQ1yjLW3mFmJJl99Y7FmyrL28OLEx"
    "Uhn01iquVwMEXajYUBcPic0euzezxP3iFqs9Y46H4BtHdMj3ItJ2j2GeqEx9"
    "JSVl/MUaL7GijhKkmky2DWMk3b5z3bKVQHefSHrC5ywPE1j0n2jVOzI4hy+s"
    "LajXv192DtOnZ4t6+L3xMSY9lgk4rqWCdrV+iD8bBeMM0v8IppOupdUTYlq2"
    "18vNZuiG1SuCz6ShQ8rYQw1/5NPwSrGewxkY3VBUWLh8m1RKIpauN+5eAfQH"
    "XEyIPWs4EUZDZmOsYijwtYcgPXfzuonwOihddtKV6+Zyu5JnoPuQZlKLT0Zr"
    "OSk4KX9phi4hBYRPBzEKu/XoqeTUbuc6i3B20h6lAza7EiNfO6Xux51jPcNc"
    "Y/48WujCncBa9gdLRdKcpsVyKqU9P1hLF2vc4mJqP+sqPQ+Wru9/T407URso"
    "6iBU+br604K4/v+B7kTEgPog9wdPhz8eKY7huKrcgK5OLdExxU2o/D+W1xrZ"
    "zAUNVWrJCo5mGoVrhQXUUDmFu856+iaxGNkGRCfBrs2rtuekN7Z5VxYBocQk"
    "s+ixtHkGBKsM6lp6X9s1s7BOH2Pce0kOqsTD8oUhH3yI7tkpbh5N50jHP6n8"
    "ZK3eMyLdxUtvuz+pvHSW1dPfZJY40jYD+Qbbf/Jb59U/0HPKRwa6ir6V4fSZ"
    "c3MBYqibl1lZOVX2mjzW8BzH6oMJ6LsBS79xZN7cYmpxLvPLZPt8rhCTK5BF"
    "6S5yMumhYbz1v+rdlxT2ZiD3kuMsIWsYNwBHR/L6DmqUMmTpqm8jT3o0VOST"
    "hmK/D67P0ks8t8m/bC+xa0Ix0wmteBOOV1MZfpEWSH4s280G3LGwnSW0AUgS"
    "ZUo1SEqflOw4pEbP6mKA5HaaFzAK36Jh0TeMl71O/2mvGoMhEi2DVeYk0aqo"
    "4RSWNNAD4ws5FglwOJm+nbzPQ3/qAQu6LJY8ZIS9ySm6kY8FlXQqo13TE2gY"
    "fP0wHne5QunpQXC8pV1LsoxMF/rIRbVexHp62cUbOt4pLGwbiGTWVteoSTop"
    "MKE8UxuzrHo8Wc1hfNGuLl7eL8BL1kyels3goeAK5nNCKofMNsZ88UecM8Wv"
    "G9ZjPguK5RzZPx0PopnX38aKaQk86/tjBnCKTpoE24B2sJZO6Vd8xagyKdfP"
    "gPubkwIT5XSlC3AqvO/uHGigW72yt95xk5QRNyeCfrybwes7rBGWTUMox3WF"
    "Mbpijfc5hyvGGkDiZRy1G8IJQqnBqZEuze+bmXAwbq8HAEAYkgyXw9+jW4IB"
    "Zqj7dNynynmrRTs49evKR59eyqx/eRODpAMr2YNRDckY3tBk/57IzFuxLxwM"
    "SxoPNWfNbdtO/Ugv0jfOu9OHwKyyrYaiKC1eae6WyKzFNz3CUrE/kmOFOlKy"
    "mtdkggUPVTbMe+fX/TFURDZCk9SzHQMNzAbPl2Ay4PVzDDPp5jGn66zVkjOR"
    "fROw8qj9Wb88r29/sdhJibzZ0SYxr4W/lMd9Tg/tW0e11m5kku24OUENgKcA"
    "BOFu5sn/10lTKVBLAQI/Az8AAgAOAHJZ81Q6lt94aQYAAJipAAAEAAAAAAAA"
    "AAAAAACAAQAAAABkYXRhUEsFBgAAAAABAAEAMgAAAIsGAAAAAA=="
)
