"""
Standard values that are useful in multiple places.
"""

DEFAULT_RESOLUTION = 0.001
"""
Default coordinate resolution in degrees.
This is typically used for
[`CodedLocation`](location/coded_location.md#nzshm_common.location.coded_location.CodedLocation) values.
"""
